/* This file was generated by syncqt. */
#ifndef QT_QTSCRIPTTOOLS_VERSION_H
#define QT_QTSCRIPTTOOLS_VERSION_H

#define QTSCRIPTTOOLS_VERSION_STR "5.15.16"

#define QTSCRIPTTOOLS_VERSION 0x050F10

#endif // QT_QTSCRIPTTOOLS_VERSION_H
